@@ -493,6 +493,7 @@ timb                                    Tim.Bunce\100pobox.com
 +                                       tim.bunce\100ig.co.uk
 tonyc                                   tony\100develop-help.com
 +                                       tony\100openbsd32.tony.develop-help.com
++                                       tony\100saturn.(none)
 
 #
 # Mere mortals.
@@ -623,6 +624,8 @@ gnat\100frii.com                        gnat\100prometheus.frii.com
 gp\100familiehaase.de                   gerrit\100familiehaase.de
 grazz\100pobox.com                      grazz\100nyc.rr.com
 gward\100ase.com                        greg\100bic.mni.mcgill.ca
+haggai\100cpan.org                      alanhaggai\100alanhaggai.org
++                                       alanhaggai\100gmail.com
 hansmu\100xs4all.nl                     hansm\100icgroup.nl
 +                                       hansm\100icgned.nl
 +                                       hans\100icgned.nl
@@ -789,7 +792,8 @@ Peter.Dintelmann\100Dresdner-Bank.com   peter.dintelmann\100dresdner-bank.com
 # NOTE: There is an intentional trailing space in the line above
 pfeifer\100wait.de                      pfeifer\100charly.informatik.uni-dortmund.de
 +                                       upf\100de.uu.net
-rabbit\100rabbit.us                     rabbit+bugs\100rabbit.us
+ribasushi@cpan.org			rabbit\100rabbit.us
++					rabbit+bugs\100rabbit.us
 perl\100aaroncrane.co.uk		arc\100cpan.org
 phil\100perkpartners.com                phil\100finchcomputer.com
 pimlott\100idiomtech.com                andrew\100pimlott.net
@@ -799,7 +803,8 @@ pne\100cpan.org                         philip.newton\100gmx.net
 +                                       philip.newton\100datenrevision.de
 +                                       pnewton\100gmx.de
 pprymmer\100factset.com                 pvhp\100forte.com
-public\100khwilliamson.com              khw\100karl.(none)
+khw\100cpan.org                         khw\100karl.(none)
++                                       public\100khwilliamson.com
 +                                       khw\100khw-desktop.(none)
 
 radu\100netsoft.ro                      rgreab\100fx.ro
