@@ -143,7 +143,16 @@ Perl_av_extend_guts(pTHX_ AV *av, SSize_t key, SSize_t *maxp, SV ***allocp,
 #endif
 		    MEM_WRAP_CHECK_1(newmax+1, SV*, oom_array_extend);
 		}
+#ifdef STRESS_REALLOC
+		{
+		    SV ** const old_alloc = *allocp;
+		    Newx(*allocp, newmax+1, SV*);
+		    Copy(old_alloc, *allocp, *maxp + 1, SV*);
+		    Safefree(old_alloc);
+		}
+#else
 		Renew(*allocp,newmax+1, SV*);
+#endif
 #ifdef Perl_safesysmalloc_size
 	      resized:
 #endif
@@ -277,7 +286,7 @@ Perl_av_fetch(pTHX_ AV *av, SSize_t key, I32 lval)
 Stores an SV in an array.  The array index is specified as C<key>.  The
 return value will be NULL if the operation failed or if the value did not
 need to be actually stored within the array (as in the case of tied
-arrays). Otherwise, it can be dereferenced
+arrays).  Otherwise, it can be dereferenced
 to get the C<SV*> that was stored
 there (= C<val>)).
 
