@@ -1,28 +1,27 @@
 package TAP::Parser::Multiplexer;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
 use IO::Select;
-use TAP::Object ();
+
+use base 'TAP::Object';
 
 use constant IS_WIN32 => $^O =~ /^(MS)?Win32$/;
 use constant IS_VMS => $^O eq 'VMS';
 use constant SELECT_OK => !( IS_VMS || IS_WIN32 );
 
-@ISA = 'TAP::Object';
-
 =head1 NAME
 
 TAP::Parser::Multiplexer - Multiplex multiple TAP::Parsers
 
 =head1 VERSION
 
-Version 3.25_01
+Version 3.30
 
 =cut
 
-$VERSION = '3.25_01';
+our $VERSION = '3.30';
 
 =head1 SYNOPSIS
 
