@@ -8,7 +8,7 @@ package Win32;
     require DynaLoader;
 
     @ISA = qw|Exporter DynaLoader|;
-    $VERSION = '0.47';
+    $VERSION = '0.49';
     $XS_VERSION = $VERSION;
     $VERSION = eval $VERSION;
 
@@ -985,7 +985,7 @@ On Windows NT 4 SP6 and later this function returns the following
 additional values: SPMAJOR, SPMINOR, SUITEMASK, PRODUCTTYPE.
 
 The version numbers for Windows 2003 and Windows Home Server are
-identical; the SUITEMASK field must be used to differentiate between\
+identical; the SUITEMASK field must be used to differentiate between
 them.
 
 The version numbers for Windows Vista and Windows Server 2008 are
@@ -1000,7 +1000,7 @@ The version numbers for Windows 8 and Windows Server 2012 are
 identical; the PRODUCTTYPE field must be used to differentiate between
 them.
 
-SPMAJOR and SPMINOR are are the version numbers of the latest
+SPMAJOR and SPMINOR are the version numbers of the latest
 installed service pack.
 
 SUITEMASK is a bitfield identifying the product suites available on
@@ -1023,7 +1023,7 @@ the system.  Known bits are:
     VER_SUITE_COMPUTE_SERVER            0x00004000
     VER_SUITE_WH_SERVER                 0x00008000
 
-The VER_SUITE_xxx names are listed here to crossreference the Microsoft
+The VER_SUITE_xxx names are listed here to cross reference the Microsoft
 documentation.  The Win32 module does not provide symbolic names for these
 constants.
 
@@ -1145,7 +1145,7 @@ and the SID type.
 
 =item Win32::MsgBox(MESSAGE [, FLAGS [, TITLE]])
 
-Create a dialogbox containing MESSAGE.  FLAGS specifies the
+Create a dialog box containing MESSAGE.  FLAGS specifies the
 required icon and buttons according to the following table:
 
 	0 = OK
