@@ -21,7 +21,7 @@ use Net::Cmd;
 use Net::Config;
 use Fcntl qw(O_WRONLY O_RDONLY O_APPEND O_CREAT O_TRUNC);
 
-$VERSION = '2.78';
+$VERSION = '2.79';
 @ISA     = qw(Exporter Net::Cmd IO::Socket::INET);
 
 # Someday I will "use constant", when I am not bothered to much about
@@ -943,7 +943,8 @@ sub _dataconn {
       PeerAddr  => join(".", @port[0 .. 3]),
       PeerPort  => $port[4] * 256 + $port[5],
       LocalAddr => ${*$ftp}{'net_ftp_localaddr'},
-      Proto     => 'tcp'
+      Proto     => 'tcp',
+      Timeout   => $ftp->timeout
     );
   }
   elsif (defined ${*$ftp}{'net_ftp_listen'}) {
@@ -1166,8 +1167,11 @@ sub pasv_wait {
   vec($rin = '', fileno($ftp), 1) = 1;
   select($rout = $rin, undef, undef, undef);
 
-  $ftp->response();
-  $non_pasv->response();
+  my $dres = $ftp->response();
+  my $sres = $non_pasv->response();
+
+  return undef
+    unless $dres == CMD_OK && $sres == CMD_OK;
 
   return undef
     unless $ftp->ok() && $non_pasv->ok();
@@ -1297,6 +1301,8 @@ C<Net::FTP> is a class implementing a simple FTP client in Perl as
 described in RFC959.  It provides wrappers for a subset of the RFC959
 commands.
 
+The Net::FTP class is a subclass of Net::Cmd and IO::Socket::INET.
+
 =head1 OVERVIEW
 
 FTP stands for File Transfer Protocol.  It is a way of transferring
@@ -1403,6 +1409,10 @@ value, with I<true> meaning that the operation was a success. When a method
 states that it returns a value, failure will be returned as I<undef> or an
 empty list.
 
+C<Net::FTP> inherits from C<Net::Cmd> so methods defined in C<Net::Cmd> may
+be used to send commands to the remote FTP server in addition to the methods
+documented here.
+
 =over 4
 
 =item login ([LOGIN [,PASSWORD [, ACCOUNT] ] ])
@@ -1701,9 +1711,6 @@ Send the QUIT command to the remote FTP server and close the socket connection.
 
 =head2 Methods for the adventurous
 
-C<Net::FTP> inherits from C<Net::Cmd> so methods defined in C<Net::Cmd> may
-be used to send commands to the remote FTP server.
-
 =over 4
 
 =item quot (CMD [,ARGS])
