@@ -143,7 +143,6 @@ esac
 
 # Shared library extension is .dylib.
 # Bundle extension is .bundle.
-ld='cc';
 so='dylib';
 dlext='bundle';
 usedl='define';
@@ -167,6 +166,11 @@ case "$ccdlflags" in		# If passed in from command line, presume user knows best
 ;;
 esac
 
+# Allow the user to override ld, but modify it as necessary below
+case "$ld" in
+    '') ld='cc';;
+esac
+
 # Perl bundles do not expect two-level namespace, added in Darwin 1.4.
 # But starting from perl 5.8.1/Darwin 7 the default is the two-level.
 case "$osvers" in
