@@ -104,7 +104,7 @@ my %exportperlmalloc =
 
 my $exportperlmalloc = $ARGS{PLATFORM} eq 'os2';
 
-my $config_h = $ARGS{PLATFORM} eq 'wince' ? 'xconfig.h' : 'config.h';
+my $config_h = 'config.h';
 open(CFG, '<', $config_h) || die "Cannot open $config_h: $!\n";
 while (<CFG>) {
     $define{$1} = 1 if /^\s*\#\s*define\s+(MYMALLOC|MULTIPLICITY
@@ -235,6 +235,12 @@ if ($ARGS{PLATFORM} ne 'vms') {
     }
 }
 
+if ($ARGS{PLATFORM} ne 'win32') {
+    ++$skip{$_} foreach qw(
+		    Perl_my_setlocale
+			 );
+}
+
 unless ($define{UNLINK_ALL_VERSIONS}) {
     ++$skip{Perl_unlnk};
 }
@@ -364,6 +370,7 @@ unless ($define{'USE_ITHREADS'}) {
 		    PL_stashpadix
 		    PL_stashpadmax
 		    Perl_alloccopstash
+		    Perl_allocfilegv
 		    Perl_clone_params_del
 		    Perl_clone_params_new
 		    Perl_parser_dup
@@ -540,6 +547,9 @@ if ($define{'PERL_GLOBAL_STRUCT'}) {
     ++$skip{$_} foreach qw(Perl_init_global_struct Perl_free_global_struct);
 }
 
+++$skip{PL_op_exec_cnt}
+    unless $define{PERL_TRACE_OPS};
+
 # functions from *.sym files
 
 my @syms = qw(globvar.sym);
@@ -631,89 +641,8 @@ if ($define{'USE_PERLIO'}) {
     # of its implementation - read from a file
     push @syms, 'perlio.sym';
 
-    # This part is then dependent on how the abstraction is implemented
-    if ($define{'USE_SFIO'}) {
-	# Old legacy non-stdio "PerlIO"
-	++$skip{$_} foreach @layer_syms;
-	++$skip{perlsio_binmode};
-	# SFIO defines most of the PerlIO routines as macros
-	# So undo most of what $perlio_sym has just done - d'oh !
-	# Perhaps it would be better to list the ones which do exist
-	# And emit them
-	++$skip{$_} foreach qw(
-			 PerlIO_canset_cnt
-			 PerlIO_clearerr
-			 PerlIO_close
-			 PerlIO_eof
-			 PerlIO_error
-			 PerlIO_exportFILE
-			 PerlIO_fast_gets
-			 PerlIO_fdopen
-			 PerlIO_fileno
-			 PerlIO_findFILE
-			 PerlIO_flush
-			 PerlIO_get_base
-			 PerlIO_get_bufsiz
-			 PerlIO_get_cnt
-			 PerlIO_get_ptr
-			 PerlIO_getc
-			 PerlIO_getname
-			 PerlIO_has_base
-			 PerlIO_has_cntptr
-			 PerlIO_importFILE
-			 PerlIO_open
-			 PerlIO_printf
-			 PerlIO_putc
-			 PerlIO_puts
-			 PerlIO_read
-			 PerlIO_releaseFILE
-			 PerlIO_reopen
-			 PerlIO_rewind
-			 PerlIO_seek
-			 PerlIO_set_cnt
-			 PerlIO_set_ptrcnt
-			 PerlIO_setlinebuf
-			 PerlIO_sprintf
-			 PerlIO_stderr
-			 PerlIO_stdin
-			 PerlIO_stdout
-			 PerlIO_stdoutf
-			 PerlIO_tell
-			 PerlIO_ungetc
-			 PerlIO_vprintf
-			 PerlIO_write
-			 PerlIO_perlio
-			 Perl_PerlIO_clearerr
-			 Perl_PerlIO_close
-			 Perl_PerlIO_eof
-			 Perl_PerlIO_error
-			 Perl_PerlIO_fileno
-			 Perl_PerlIO_fill
-			 Perl_PerlIO_flush
-			 Perl_PerlIO_get_base
-			 Perl_PerlIO_get_bufsiz
-			 Perl_PerlIO_get_cnt
-			 Perl_PerlIO_get_ptr
-			 Perl_PerlIO_read
-			 Perl_PerlIO_seek
-			 Perl_PerlIO_set_cnt
-			 Perl_PerlIO_set_ptrcnt
-			 Perl_PerlIO_setlinebuf
-			 Perl_PerlIO_stderr
-			 Perl_PerlIO_stdin
-			 Perl_PerlIO_stdout
-			 Perl_PerlIO_tell
-			 Perl_PerlIO_unread
-			 Perl_PerlIO_write
-                         PL_def_layerlist
-                         PL_known_layers
-                         PL_perlio
-			     );
-    }
-    else {
-	# PerlIO with layers - export implementation
-	try_symbols(@layer_syms, 'perlsio_binmode');
-    }
+    # PerlIO with layers - export implementation
+    try_symbols(@layer_syms, 'perlsio_binmode');
 } else {
 	# -Uuseperlio
 	# Skip the PerlIO layer symbols - although
@@ -801,9 +730,7 @@ try_symbols(qw(
 		    PerlIO_getpos
 		    PerlIO_init
 		    PerlIO_setpos
-		    PerlIO_sprintf
 		    PerlIO_tmpfile
-		    PerlIO_vsprintf
 	     ));
 
 if ($ARGS{PLATFORM} eq 'win32') {
